==> Rmixmod_1.0.tar.gz: Rmixmod/src/MIXMOD/XEMCVCriterion.h <==
/***************************************************************************
                             SRC/MIXMOD/XEMCVCriterion.h  description
    copyright            : (C) MIXMOD Team - 2001-2011
    email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
    This file is part of MIXMOD
    
    MIXMOD is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MIXMOD is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.

    All informations available on : http://www.mixmod.org                                                                                               
***************************************************************************/
#ifndef XEMCVCRITERION_H
#define XEMCVCRITERION_H


#include "XEMCriterion.h"
#include "XEMModel.h"
#include "XEMClusteringInput.h"

/**
  @brief Derived class of XEMCriterion for CV Criterion
  @author F Langrognet &  A Echenim
  */

class XEMCVCriterion : public XEMCriterion{

public:

  /// Default constructor
  XEMCVCriterion();


  /// Constructor
  XEMCVCriterion(XEMOldInput * input);
  
  /// Destructor
  virtual ~XEMCVCriterion();
  
  XEMCriterionName getCriterionName() const;

  /// Run method
  void run(XEMModel * model, double & value,  XEMErrorType & error);
  
  /// Run method
  void run(XEMModel * model, double & value, int64_t *& cvLabel, XEMErrorType & error);

  
private :


  void createCVBlocks(XEMModel * model);
  
  /// Table of XEMCVBlock : testBlock
  XEMCVBlock * _tabCVBlock;
  
  // number of CV Blocks  
  int64_t _nbCVBlock;
  
  // initialisation method of cv blocks
  XEMCVinitBlocks _CVinitBlocks;
};

inline void XEMCVCriterion::run(XEMModel * model, double & value,  XEMErrorType & error){
  throw internalMixmodError;
}

inline XEMCriterionName XEMCVCriterion::getCriterionName() const{
  return CV;
}

#endif

==> Rmixmod_1.1.2.tar.gz: Rmixmod/src/MIXMOD/XEMCVCriterion.h <==
/***************************************************************************
                             SRC/MIXMOD/XEMCVCriterion.h  description
    copyright            : (C) MIXMOD Team - 2001-2011
    email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
    This file is part of MIXMOD
    
    MIXMOD is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MIXMOD is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.

    All informations available on : http://www.mixmod.org                                                                                               
***************************************************************************/
#ifndef XEMCVCRITERION_H
#define XEMCVCRITERION_H


#include "XEMCriterion.h"

// pre-declaration
class XEMLabelDescription;

/**
  @brief Derived class of XEMCriterion for CV Criterion
  @author F Langrognet &  A Echenim
  */

class XEMCVCriterion : public XEMCriterion{

public:

  /// Default constructor
  XEMCVCriterion( XEMModel * model
                , const int64_t nbCVBlock
                );
  
  /// Destructor
  virtual ~XEMCVCriterion();
  
  /// Run method
  virtual void run(XEMCriterionOutput & output);

  /// Accessor
  std::vector<int64_t> & getCVLabel();
  
private :

  void createCVBlocks();
  
  /// Table of XEMCVBlock : testBlock
  XEMCVBlock* _tabCVBlock;
  
  // pointer to a XEMLabelDescription
  std::vector<int64_t> _cvLabel;
  
  // number of CV Blocks  
  int64_t _nbCVBlock;
    
  // initialisation method of cv blocks
  XEMCVinitBlocks _CVinitBlocks;
};


inline std::vector<int64_t> & XEMCVCriterion::getCVLabel(){
  return _cvLabel;
}

#endif
